Struct quantized_density_fields::id::ID [−][src]
pub struct ID(_);
Methods
impl ID[src]
impl IDTrait Implementations
impl PartialEq for ID[src]
impl PartialEq for IDfn eq(&self, other: &ID) -> bool[src]
fn eq(&self, other: &ID) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &ID) -> bool[src]
fn ne(&self, other: &ID) -> boolThis method tests for !=.
impl Eq for ID[src]
impl Eq for IDimpl Hash for ID[src]
impl Hash for IDfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Copy for ID[src]
impl Copy for IDimpl Clone for ID[src]
impl Clone for IDfn clone(&self) -> ID[src]
fn clone(&self) -> IDReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl PartialOrd for ID[src]
impl PartialOrd for IDfn partial_cmp(&self, other: &ID) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &ID) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &ID) -> bool[src]
fn lt(&self, other: &ID) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &ID) -> bool[src]
fn le(&self, other: &ID) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &ID) -> bool[src]
fn gt(&self, other: &ID) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &ID) -> bool[src]
fn ge(&self, other: &ID) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for ID[src]
impl Ord for IDfn cmp(&self, other: &ID) -> Ordering[src]
fn cmp(&self, other: &ID) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl Default for ID[src]
impl Default for IDimpl Debug for ID[src]
impl Debug for IDfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl ToString for ID[src]
impl ToString for ID